diff src/video/riscos/SDL_riscostask.c @ 1035:974ba6ae0fa3

Date: Wed, 26 Jan 2005 13:37:09 GMT From: Peter Naulls Subject: RISC OS SDL Patches Sam, I've attached a diff of the latest changes to libSDL for RISC OS support. These changes are by Alan Buckley and myself. The most significant of these are: Optimised assembler blit rountines - I've attached the file src/video/riscos/SDL_riscosASM.s which is needed for this. Move to using /dev/dsp instead of its own audio implementation. This means that src/audio/riscos/SDL_drenderer.c should be removed Typo fixes. Mainly correct spelling of "RISC OS", but some from elsewhere too.
author Sam Lantinga <slouken@libsdl.org>
date Sat, 12 Feb 2005 18:01:31 +0000
parents d74fbf56f2f6
children de22ea8440d2
line wrap: on
line diff
--- a/src/video/riscos/SDL_riscostask.c	Sat Jan 29 09:58:40 2005 +0000
+++ b/src/video/riscos/SDL_riscostask.c	Sat Feb 12 18:01:31 2005 +0000
@@ -21,7 +21,7 @@
 */
 
 /*
-    This file added by Alan Buckley (alan_baa@hotmail.com) to support RISCOS 
+    This file added by Alan Buckley (alan_baa@hotmail.com) to support RISC OS 
 	26 March 2003
 
 	File includes routines for:
@@ -44,7 +44,7 @@
 pthread_t main_thread;
 #endif
 
-/* RISCOS variables */
+/* RISC OS variables */
 
 static int task_handle = 0;
 static int wimp_version = 0;
@@ -84,7 +84,7 @@
 
 /******************************************************************
 
- Initialise as RISCOS Wimp task
+ Initialise as RISC OS Wimp task
 
 *******************************************************************/
 
@@ -169,7 +169,7 @@
 		   there is a variable set up in the form SDL$<name>$TaskName
 		   in which case the value of this variable will be used.
 
-		   Now also gets other riscos configuration varibles
+		   Now also gets other RISC OS configuration varibles
                 SDL$<name>$BackBuffer - set to 1 to use a system memory backbuffer in fullscreen mode
 						    so updates wait until a call to SDL_UpdateRects. (default 0)
 						    This is required for programmes where they have assumed this is
@@ -226,7 +226,7 @@
 
 	   if (*p)
 	   {
 		   /* Read variables that effect the RISCOS SDL engine for this task */
 		   env_var = malloc(strlen(p) + 18); /* 18 is larger than the biggest variable name */
 		   if (env_var)
 		   {
@@ -246,7 +246,7 @@
 			   strcat(env_var, "$BackBuffer");
 
 			   env_val = getenv(env_var);
-			   if (env_val && strcmp(env_val,"1") == 0) riscos_backbuffer = 1;
+			   if (env_val) riscos_backbuffer = atoi(env_val);
 
 			   strcpy(env_var, "SDL$");
 			   strcat(env_var, p);
@@ -226,7 +226,7 @@
 	   if (*p)
 	   {
-		   /* Read variables that effect the RISCOS SDL engine for this task */
+		   /* Read variables that effect the RISC OS SDL engine for this task */
 		   env_var = malloc(strlen(p) + 18); /* 18 is larger than the biggest variable name */
 		   if (env_var)